@@ -14,21 +14,24 @@ import pandas as pd
 import requests
 
 DIR = os.path.dirname(__file__)
+_PREFIX = ''
 _FILE_ENDING = ''
 if sys.platform.startswith('linux'):
     _FILE_ENDING = '.so'
+    _PREFIX = 'lib'
 elif sys.platform.startswith('win32'):
     _FILE_ENDING = '.dll'
 elif sys.platform.startswith('darwin'):
     _FILE_ENDING = '.dylib'
+    _PREFIX = 'lib'
 
 # initialize vtl
-VTL = ctypes.cdll.LoadLibrary(os.path.join(DIR, 'vocaltractlab_api/libVocalTractLabApi' + _FILE_ENDING))
+VTL = ctypes.cdll.LoadLibrary(os.path.join(DIR, f'vocaltractlab_api/{_PREFIX}VocalTractLabApi{_FILE_ENDING}'))
 SPEAKER_FILE_NAME = ctypes.c_char_p(os.path.join(DIR, 'vocaltractlab_api/JD3.speaker').encode())
 FAILURE = VTL.vtlInitialize(SPEAKER_FILE_NAME)
 if FAILURE != 0:
     raise ValueError('Error in vtlInitialize! Errorcode: %i' % FAILURE)
-del SPEAKER_FILE_NAME, FAILURE, _FILE_ENDING
+del SPEAKER_FILE_NAME, FAILURE, _FILE_ENDING, _PREFIX
 
 # get version / compile date
 VERSION = ctypes.c_char_p(b' ' * 64)
@@ -838,7 +841,8 @@ def ges_to_cps(ges_file):
         cps = read_cp(tract_sequence_file_name.decode())
     return cps
 
-def get_area_info_within_oral_cavity(tube_length, tube_area, cm_inside=7, calculate="min"):
+
+def get_area_info_within_oral_cavity(tube_length, tube_area, *, cm_inside=7, calculate="min"):
     """
     Extracts the tube area information within the oral cavity for a given number of cm starting from the lips.
 
@@ -858,14 +862,18 @@ def get_area_info_within_oral_cavity(tube_length, tube_area, cm_inside=7, calcul
     section_area_per_time : np.array
         the extracted area information per time (seq_length, )
     """
-    
-    length_per_time = np.cumsum(tube_length,axis=1)
+    length_per_time = np.cumsum(tube_length, axis=1)
     section_area_per_time = []
     for t, l in enumerate(length_per_time):
-        steps = [length_per_time[t][-1]-i*1 for i in range(cm_inside+1)][::-1]
+        steps = [length_per_time[t][-1] - i * 1 for i in range(cm_inside + 1)][::-1]
         section_area = []
-        for i,step in enumerate(steps[:-1]):
-            area = tube_area[t,np.where(np.logical_and(l>=step, l<=steps[i+1]))][0]
+        for i, step in enumerate(steps[:-1]):
+            indices = np.where(np.logical_and(l>=step, l<=steps[i+1]))[0]
+            # add one more index, if possible as the next tube section is
+            # paritally in this interval
+            if indices[-1] < tube_area.shape[1] - 1:
+                indices = np.concatenate((indices, indices[-1:] + 1))
+            area = tube_area[t, indices]
             if calculate == "raw":
                 section_area += [area]
             elif calculate == "mean":
@@ -887,14 +895,28 @@ def download_pretrained_weights(*, skip_if_exists=True, verbose=True):
         if skip_if_exists:
             if verbose:
                 print(f"pretrained_models exist already. Skip download. Path is {model_weights_path}")
+                print(f'Version of pretrained weights is "{get_pretrained_weights_version()}"')
             return
         shutil.rmtree(model_weights_path)
 
     zip_file_url = "https://nc.mlcloud.uni-tuebingen.de/index.php/s/N4nik8wgxwQHP83/download"
     if verbose:
-        print(f"downloading 114 MB of pretrained weights from {zip_file_url}")
+        print(f"downloading 200 MB of pretrained weights from {zip_file_url}")
         print(f"saving pretrained weights to {model_weights_path}")
     stream = requests.get(zip_file_url, stream=True)
     zip_file = zipfile.ZipFile(io.BytesIO(stream.content))
     zip_file.extractall(package_path)
+    if verbose:
+        print(f'Version of pretrained weights is "{get_pretrained_weights_version()}"')
+
+
+def get_pretrained_weights_version():
+    """read and return the version of the pretrained weights, <No version file
+    found> if no pretrained weights exist"""
+    version_path = os.path.join(DIR, 'pretrained_models/version.txt')
+    if not os.path.exists(version_path):
+        return f"<No version file found at {version_path}>"
+    with open(version_path, 'rt') as vfile:
+        version = vfile.read().strip()
+    return version
 
